@@ -1,6 +1,6 @@
 /*
  * Copyright 2013-2016 Canonical Ltd.
- * Copyright 2021 Robert Tari
+ * Copyright 2021-2022 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -200,14 +200,6 @@ device_compare_func (gconstpointer ga, gconstpointer gb)
     }
 
   state = UP_DEVICE_STATE_DISCHARGING;
-
-  /* discharging items with more than 10% remaining always lose */
-  if (!ret && (((a_state == state) && !a_time && (a_percentage > 10))))
-      ret = 1;
-
-  if (!ret && (((b_state == state) && !b_time && (b_percentage > 10))))
-      ret = -1;
-
   if (!ret && (((a_state == state) && a_time) ||
                ((b_state == state) && b_time)))
     {
@@ -455,6 +447,8 @@ create_header_state (IndicatorPowerService * self)
 
   g_variant_builder_add (&b, "{sv}", "title", g_variant_new_string (_("Battery")));
 
+  g_variant_builder_add (&b, "{sv}", "tooltip", g_variant_new_string (_("Battery status and power management")));
+
   g_variant_builder_add (&b, "{sv}", "visible",
                          g_variant_new_boolean (should_be_visible (self)));
 
@@ -487,7 +481,7 @@ create_header_state (IndicatorPowerService * self)
             g_free (title);
         }
 
-      if ((icon = indicator_power_device_get_gicon (p->primary_device)))
+      if ((icon = indicator_power_device_get_gicon (p->primary_device, TRUE)))
         {
           GVariant * serialized_icon = g_icon_serialize (icon);
 
@@ -528,7 +522,7 @@ append_device_to_menu (GMenu * menu, const IndicatorPowerDevice * device, int pr
 
     g_menu_item_set_attribute (item, "x-ayatana-type", "s", "org.ayatana.indicator.basic");
 
-    if ((icon = indicator_power_device_get_gicon (device)))
+    if ((icon = indicator_power_device_get_gicon (device, FALSE)))
       {
         GVariant * serialized_icon = g_icon_serialize (icon);
 
@@ -672,7 +666,7 @@ create_phone_settings_section(IndicatorPowerService * self)
 
   if (ab_supported)
     {
-      item = g_menu_item_new(_("Adjust brightness automatically"), "indicator.auto-brightness");
+      item = g_menu_item_new(_("Adjust brightness automatically"), "indicator.auto-brightness(true)");
       g_menu_item_set_attribute(item, "x-ayatana-type", "s", "org.ayatana.indicator.switch");
       g_menu_append_item(section, item);
       g_object_unref(item);
@@ -680,13 +674,13 @@ create_phone_settings_section(IndicatorPowerService * self)
 
   if (flashlight_supported())
   {
-    item = g_menu_item_new(_("Flashlight"), "indicator.flashlight");
+    item = g_menu_item_new(_("Flashlight"), "indicator.flashlight(true)");
     g_menu_item_set_attribute(item, "x-ayatana-type", "s", "org.ayatana.indicator.switch");
     g_menu_append_item(section, item);
     g_object_unref(item);
     if (flashlight_activated())
     {
-      item = g_menu_item_new(_("Warning: Heavy use can damage the LED!"), "indicator.flashlight");
+      item = g_menu_item_new(_("Warning: Heavy use can damage the LED!"), "indicator.flashlight(true)");
       g_menu_append_item(section, item);
       g_object_unref(item);
     }
@@ -921,7 +915,9 @@ init_gactions (IndicatorPowerService * self)
   p->device_state_action = a;
 
   /* add the auto-brightness action */
-  a = g_simple_action_new_stateful("auto-brightness", NULL, g_variant_new_boolean(FALSE));
+  GVariantType *pType = g_variant_type_new ("b");
+  a = g_simple_action_new_stateful ("auto-brightness", pType, g_variant_new_boolean (FALSE));
+  g_variant_type_free (pType);
   g_object_bind_property_full(p->brightness, "auto-brightness",
                               a,  "state",
                               G_BINDING_SYNC_CREATE|G_BINDING_BIDIRECTIONAL,
@@ -931,7 +927,9 @@ init_gactions (IndicatorPowerService * self)
   g_action_map_add_action(G_ACTION_MAP(p->actions), G_ACTION(a));
 
   /* add the flashlight action */
-  a = g_simple_action_new_stateful("flashlight", NULL, g_variant_new_boolean(FALSE));
+  pType = g_variant_type_new ("b");
+  a = g_simple_action_new_stateful ("flashlight", pType, g_variant_new_boolean (FALSE));
+  g_variant_type_free (pType);
   g_action_map_add_action (G_ACTION_MAP(p->actions), G_ACTION(a));
   g_signal_connect(a, "activate", G_CALLBACK(toggle_flashlight_action), self);
 
